aboutsummaryrefslogtreecommitdiff
path: root/test
diff options
context:
space:
mode:
authorSebastian Falbesoner <sebastian.falbesoner@gmail.com>2020-07-22 01:49:09 +0200
committerSebastian Falbesoner <sebastian.falbesoner@gmail.com>2020-08-12 22:21:38 +0200
commit6d941923c318ce9cb2380d3e41ffb760636656a2 (patch)
tree0f56a3537ca9c94dfb9b9ad3cebfe9aecd14c1f1 /test
parentcb1ee1551cf39905ccb67e3d07b0e3aaaca18ce3 (diff)
downloadbitcoin-6d941923c318ce9cb2380d3e41ffb760636656a2.tar.xz
test: add logging for p2p_feefilter.py
Diffstat (limited to 'test')
-rwxr-xr-xtest/functional/p2p_feefilter.py12
1 files changed, 5 insertions, 7 deletions
diff --git a/test/functional/p2p_feefilter.py b/test/functional/p2p_feefilter.py
index 0b51d8f4bb..c58c972c9b 100755
--- a/test/functional/p2p_feefilter.py
+++ b/test/functional/p2p_feefilter.py
@@ -88,24 +88,22 @@ class FeeFilterTest(BitcoinTestFramework):
conn = self.nodes[0].add_p2p_connection(TestP2PConn())
- # Test that invs are received by test connection for all txs at
- # feerate of .2 sat/byte
+ self.log.info("Test txs paying 0.2 sat/byte are received by test connection")
node1.settxfee(Decimal("0.00000200"))
txids = [node1.sendtoaddress(node1.getnewaddress(), 1) for _ in range(3)]
assert allInvsMatch(txids, conn)
conn.clear_invs()
# Set a filter of .15 sat/byte on test connection
conn.send_and_ping(msg_feefilter(150))
- # Test that txs are still being received by test connection (paying .15 sat/byte)
+ self.log.info("Test txs paying 0.15 sat/byte are received by test connection")
node1.settxfee(Decimal("0.00000150"))
txids = [node1.sendtoaddress(node1.getnewaddress(), 1) for _ in range(3)]
assert allInvsMatch(txids, conn)
conn.clear_invs()
- # Change tx fee rate to .1 sat/byte and test they are no longer received
- # by the test connection
+ self.log.info("Test txs paying 0.1 sat/byte are no longer received by test connection")
node1.settxfee(Decimal("0.00000100"))
[node1.sendtoaddress(node1.getnewaddress(), 1) for _ in range(3)]
self.sync_mempools() # must be sure node 0 has received all txs
@@ -122,7 +120,7 @@ class FeeFilterTest(BitcoinTestFramework):
assert allInvsMatch(txids, conn)
conn.clear_invs()
- # Remove fee filter and check that txs are received again
+ self.log.info("Remove fee filter and check txs are received again")
conn.send_and_ping(msg_feefilter(0))
txids = [node1.sendtoaddress(node1.getnewaddress(), 1) for _ in range(3)]
assert allInvsMatch(txids, conn)
@@ -88,24 +88,22 @@ class FeeFilterTest(BitcoinTestFramework):
assert allInvsMatch(txids, conn)
conn.clear_invs()
- # Set a filter of .15 sat/byte on test connection
+ # Set a fee filter of 0.15 sat/byte on test connection
conn.send_and_ping(msg_feefilter(150))